==> haskell-generic-lens-2.0.0.0-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-lens.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-lens
version:              2.0.0.0
visibility:           public
id:                   generic-lens-2.0.0.0-IBOb1wf4Q0kBEEh8TR20wL
key:                  generic-lens-2.0.0.0-IBOb1wf4Q0kBEEh8TR20wL
license:              BSD-3-Clause
maintainer:           kiss.csongor.kiss@gmail.com
author:               Csongor Kiss
homepage:             https://github.com/kcsongor/generic-lens
synopsis:             Generically derive traversals, lenses and prisms.
description:
    This library uses GHC.Generics to derive efficient optics (traversals, lenses and prisms) for algebraic data types in a type-directed way, with a focus on good type inference and error messages when possible.

    The library exposes a van Laarhoven interface. For an alternative interface, supporting an opaque optic type, see
    @<https://hackage.haskell.org/package/generic-optics generic-optics>@.

category:             Generics, Records, Lens
abi:                  6e31840edd29c23b8bfd56008d9caec2
exposed:              True
exposed-modules:
    Data.Generics.Internal.VL Data.Generics.Internal.VL.Iso
    Data.Generics.Internal.VL.Lens Data.Generics.Internal.VL.Prism
    Data.Generics.Labels Data.Generics.Product
    Data.Generics.Product.Any Data.Generics.Product.Fields
    Data.Generics.Product.HList Data.Generics.Product.Param
    Data.Generics.Product.Positions Data.Generics.Product.Subtype
    Data.Generics.Product.Typed Data.Generics.Product.Types
    Data.Generics.Sum Data.Generics.Sum.Any
    Data.Generics.Sum.Constructors Data.Generics.Sum.Subtype
    Data.Generics.Sum.Typed Data.Generics.Wrapped

import-dirs:          /usr/lib/ghc-8.10.2/site-local/generic-lens-2.0.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/generic-lens-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/generic-lens-2.0.0.0
hs-libraries:         HSgeneric-lens-2.0.0.0-IBOb1wf4Q0kBEEh8TR20wL
depends:
    base-4.14.1.0 generic-lens-core-2.0.0.0-KIFiLKUEV3B5vOD912muTq
    profunctors-5.6-8x1AGK78dHCD3J1CtThR0Y text-1.2.3.2

haddock-interfaces:
    /usr/share/doc/haskell-generic-lens/html/generic-lens.haddock

haddock-html:         /usr/share/doc/haskell-generic-lens/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-lens-2.0.0.0-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-lens.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-lens
version:              2.0.0.0
visibility:           public
id:                   generic-lens-2.0.0.0-GeSor0PCvQZAufqs0VYc4d
key:                  generic-lens-2.0.0.0-GeSor0PCvQZAufqs0VYc4d
license:              BSD-3-Clause
maintainer:           kiss.csongor.kiss@gmail.com
author:               Csongor Kiss
homepage:             https://github.com/kcsongor/generic-lens
synopsis:             Generically derive traversals, lenses and prisms.
description:
    This library uses GHC.Generics to derive efficient optics (traversals, lenses and prisms) for algebraic data types in a type-directed way, with a focus on good type inference and error messages when possible.

    The library exposes a van Laarhoven interface. For an alternative interface, supporting an opaque optic type, see
    @<https://hackage.haskell.org/package/generic-optics generic-optics>@.

category:             Generics, Records, Lens
abi:                  59f4ae3c45199eec5979fb53bbad57bf
exposed:              True
exposed-modules:
    Data.Generics.Internal.VL Data.Generics.Internal.VL.Iso
    Data.Generics.Internal.VL.Lens Data.Generics.Internal.VL.Prism
    Data.Generics.Labels Data.Generics.Product
    Data.Generics.Product.Any Data.Generics.Product.Fields
    Data.Generics.Product.HList Data.Generics.Product.Param
    Data.Generics.Product.Positions Data.Generics.Product.Subtype
    Data.Generics.Product.Typed Data.Generics.Product.Types
    Data.Generics.Sum Data.Generics.Sum.Any
    Data.Generics.Sum.Constructors Data.Generics.Sum.Subtype
    Data.Generics.Sum.Typed Data.Generics.Wrapped

import-dirs:          /usr/lib/ghc-8.10.2/site-local/generic-lens-2.0.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/generic-lens-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/generic-lens-2.0.0.0
hs-libraries:         HSgeneric-lens-2.0.0.0-GeSor0PCvQZAufqs0VYc4d
depends:
    base-4.14.1.0 generic-lens-core-2.0.0.0-KIFiLKUEV3B5vOD912muTq
    profunctors-5.6-AiReZ3JbdTCCNfrTKCHLlV text-1.2.3.2

haddock-interfaces:
    /usr/share/doc/haskell-generic-lens/html/generic-lens.haddock

haddock-html:         /usr/share/doc/haskell-generic-lens/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
